package Firewall::Config::Element::Service::Asa;

#------------------------------------------------------------------------------
# 加载扩展模块
#------------------------------------------------------------------------------
use Moose;
use namespace::autoclean;
use Firewall::Config::Element::ServiceMeta::Asa;

#------------------------------------------------------------------------------
# 引入 Firewall::Config::Element::Service::Role 角色
#------------------------------------------------------------------------------
with 'Firewall::Config::Element::Service::Role';

#------------------------------------------------------------------------------
# Firewall::Config::Element::Service::Asa 通用属性
#------------------------------------------------------------------------------
has dstPort => ( is => 'ro', isa => 'Str', required => 1, );

#------------------------------------------------------------------------------
# 重写 Firewall::Config::Element::Role => _buildRange 方法
#------------------------------------------------------------------------------
sub _buildSign {
  my $self = shift;
  return $self->createSign( $self->srvName );
}

__PACKAGE__->meta->make_immutable;
1;
